# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: playwright.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='playwright.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10playwright.proto\"\xd2\x06\n\x07Request\x1a\x07\n\x05\x45mpty\x1a\x1e\n\x0eScreenshotPath\x12\x0c\n\x04path\x18\x01 \x01(\t\x1a@\n\x07\x42rowser\x12\x0f\n\x07\x62rowser\x18\x01 \x01(\t\x12\x10\n\x08headless\x18\x02 \x01(\x08\x12\x12\n\nrawOptions\x18\x03 \x01(\t\x1a\x1d\n\x07\x43ontext\x12\x12\n\nrawOptions\x18\x01 \x01(\t\x1a\x12\n\x03Url\x12\x0b\n\x03url\x18\x01 \x01(\t\x1a:\n\tTextInput\x12\r\n\x05input\x18\x01 \x01(\t\x12\x10\n\x08selector\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x08\x1a\x35\n\x0f\x45lementProperty\x12\x10\n\x08property\x18\x01 \x01(\t\x12\x10\n\x08selector\x18\x02 \x01(\t\x1aH\n\x08TypeText\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x05\x12\r\n\x05\x63lear\x18\x04 \x01(\x08\x1a*\n\x08\x46illText\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x1a\x1d\n\tClearText\x12\x10\n\x08selector\x18\x01 \x01(\t\x1a*\n\tPressKeys\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x03(\t\x1a#\n\x0f\x45lementSelector\x12\x10\n\x08selector\x18\x01 \x01(\t\x1a\x1a\n\x07Timeout\x12\x0f\n\x07timeout\x18\x01 \x01(\x02\x1a\x16\n\x05Index\x12\r\n\x05index\x18\x01 \x01(\x05\x1a\x1b\n\x08StyleTag\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x1a?\n\x1a\x45lementSelectorWithOptions\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x0f\n\x07options\x18\x02 \x01(\t\x1a\x41\n\x1b\x45lementSelectorWithDuration\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\x05\x1a>\n\x15SelectElementSelector\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x13\n\x0bmatcherJson\x18\x02 \x01(\t\x1a \n\x0eJavascriptCode\x12\x0e\n\x06script\x18\x01 \x01(\t\x1a\x19\n\x07RawJson\x12\x0e\n\x06script\x18\x01 \x01(\t\"=\n\x0bSelectEntry\x12\r\n\x05value\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x10\n\x08selected\x18\x04 \x01(\x08\"\xeb\x01\n\x08Response\x1a\x14\n\x05\x45mpty\x12\x0b\n\x03log\x18\x01 \x01(\t\x1a#\n\x06String\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x1a!\n\x04\x42ool\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\x08\x1a \n\x03Int\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\x05\x1a%\n\x06Select\x12\x1b\n\x05\x65ntry\x18\x01 \x03(\x0b\x32\x0c.SelectEntry\x1a\x38\n\x19JavascriptExecutionResult\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\t2\x93\x11\n\nPlaywright\x12=\n\x0eTakeScreenshot\x12\x17.Request.ScreenshotPath\x1a\x10.Response.String\"\x00\x12\x31\n\x0c\x43loseBrowser\x12\x0e.Request.Empty\x1a\x0f.Response.Empty\"\x00\x12\'\n\x04GoTo\x12\x0c.Request.Url\x1a\x0f.Response.Empty\"\x00\x12)\n\x06GoBack\x12\x0c.Request.Url\x1a\x0f.Response.Empty\"\x00\x12,\n\tGoForward\x12\x0c.Request.Url\x1a\x0f.Response.Empty\"\x00\x12.\n\x08GetTitle\x12\x0e.Request.Empty\x1a\x10.Response.String\"\x00\x12<\n\x0fGetElementCount\x12\x18.Request.ElementSelector\x1a\r.Response.Int\"\x00\x12\x32\n\tInputText\x12\x12.Request.TextInput\x1a\x0f.Response.Empty\"\x00\x12\x30\n\x08TypeText\x12\x11.Request.TypeText\x1a\x0f.Response.Empty\"\x00\x12\x30\n\x08\x46illText\x12\x11.Request.FillText\x1a\x0f.Response.Empty\"\x00\x12\x32\n\tClearText\x12\x12.Request.ClearText\x1a\x0f.Response.Empty\"\x00\x12>\n\x0eGetDomProperty\x12\x18.Request.ElementProperty\x1a\x10.Response.String\"\x00\x12=\n\x0fGetBoolProperty\x12\x18.Request.ElementProperty\x1a\x0e.Response.Bool\"\x00\x12>\n\x0eGetTextContent\x12\x18.Request.ElementSelector\x1a\x10.Response.String\"\x00\x12,\n\x06GetUrl\x12\x0e.Request.Empty\x1a\x10.Response.String\"\x00\x12\x34\n\x05\x43lick\x12\x18.Request.ElementSelector\x1a\x0f.Response.Empty\"\x00\x12.\n\x05Press\x12\x12.Request.PressKeys\x1a\x0f.Response.Empty\"\x00\x12@\n\x10GetSelectContent\x12\x18.Request.ElementSelector\x1a\x10.Response.Select\"\x00\x12\x41\n\x0cSelectOption\x12\x1e.Request.SelectElementSelector\x1a\x0f.Response.Empty\"\x00\x12=\n\x0e\x44\x65selectOption\x12\x18.Request.ElementSelector\x1a\x0f.Response.Empty\"\x00\x12<\n\rCheckCheckbox\x12\x18.Request.ElementSelector\x1a\x0f.Response.Empty\"\x00\x12>\n\x0fUncheckCheckbox\x12\x18.Request.ElementSelector\x1a\x0f.Response.Empty\"\x00\x12,\n\x06Health\x12\x0e.Request.Empty\x1a\x10.Response.String\"\x00\x12\x31\n\nSetTimeout\x12\x10.Request.Timeout\x1a\x0f.Response.Empty\"\x00\x12\x33\n\x0b\x41\x64\x64StyleTag\x12\x11.Request.StyleTag\x1a\x0f.Response.Empty\"\x00\x12L\n\x11HighlightElements\x12$.Request.ElementSelectorWithDuration\x1a\x0f.Response.Empty\"\x00\x12J\n\x10\x43lickWithOptions\x12#.Request.ElementSelectorWithOptions\x1a\x0f.Response.Empty\"\x00\x12\x34\n\x05\x46ocus\x12\x18.Request.ElementSelector\x1a\x0f.Response.Empty\"\x00\x12N\n\x14WaitForElementsState\x12#.Request.ElementSelectorWithOptions\x1a\x0f.Response.Empty\"\x00\x12Y\n\x17\x45xecuteJavascriptOnPage\x12\x17.Request.JavascriptCode\x1a#.Response.JavascriptExecutionResult\"\x00\x12\x45\n\x0cGetPageState\x12\x0e.Request.Empty\x1a#.Response.JavascriptExecutionResult\"\x00\x12\x36\n\x11\x41utoActivatePages\x12\x0e.Request.Empty\x1a\x0f.Response.Empty\"\x00\x12/\n\nSwitchPage\x12\x0e.Request.Index\x1a\x0f.Response.Empty\"\x00\x12\x32\n\rSwitchContext\x12\x0e.Request.Index\x1a\x0f.Response.Empty\"\x00\x12\x32\n\rSwitchBrowser\x12\x0e.Request.Index\x1a\x0f.Response.Empty\"\x00\x12-\n\nCreatePage\x12\x0c.Request.Url\x1a\x0f.Response.Empty\"\x00\x12\x34\n\rCreateContext\x12\x10.Request.Context\x1a\x0f.Response.Empty\"\x00\x12\x34\n\rCreateBrowser\x12\x10.Request.Browser\x1a\x0f.Response.Empty\"\x00\x62\x06proto3'
)




_REQUEST_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='Request.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=39,
)

_REQUEST_SCREENSHOTPATH = _descriptor.Descriptor(
  name='ScreenshotPath',
  full_name='Request.ScreenshotPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Request.ScreenshotPath.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=71,
)

_REQUEST_BROWSER = _descriptor.Descriptor(
  name='Browser',
  full_name='Request.Browser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='browser', full_name='Request.Browser.browser', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headless', full_name='Request.Browser.headless', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rawOptions', full_name='Request.Browser.rawOptions', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=137,
)

_REQUEST_CONTEXT = _descriptor.Descriptor(
  name='Context',
  full_name='Request.Context',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rawOptions', full_name='Request.Context.rawOptions', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=168,
)

_REQUEST_URL = _descriptor.Descriptor(
  name='Url',
  full_name='Request.Url',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='Request.Url.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=188,
)

_REQUEST_TEXTINPUT = _descriptor.Descriptor(
  name='TextInput',
  full_name='Request.TextInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='Request.TextInput.input', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.TextInput.selector', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Request.TextInput.type', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=248,
)

_REQUEST_ELEMENTPROPERTY = _descriptor.Descriptor(
  name='ElementProperty',
  full_name='Request.ElementProperty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='property', full_name='Request.ElementProperty.property', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ElementProperty.selector', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=303,
)

_REQUEST_TYPETEXT = _descriptor.Descriptor(
  name='TypeText',
  full_name='Request.TypeText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.TypeText.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='Request.TypeText.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='Request.TypeText.delay', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear', full_name='Request.TypeText.clear', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=377,
)

_REQUEST_FILLTEXT = _descriptor.Descriptor(
  name='FillText',
  full_name='Request.FillText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.FillText.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='Request.FillText.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=421,
)

_REQUEST_CLEARTEXT = _descriptor.Descriptor(
  name='ClearText',
  full_name='Request.ClearText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ClearText.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=452,
)

_REQUEST_PRESSKEYS = _descriptor.Descriptor(
  name='PressKeys',
  full_name='Request.PressKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.PressKeys.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='Request.PressKeys.key', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=496,
)

_REQUEST_ELEMENTSELECTOR = _descriptor.Descriptor(
  name='ElementSelector',
  full_name='Request.ElementSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ElementSelector.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=533,
)

_REQUEST_TIMEOUT = _descriptor.Descriptor(
  name='Timeout',
  full_name='Request.Timeout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='Request.Timeout.timeout', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=535,
  serialized_end=561,
)

_REQUEST_INDEX = _descriptor.Descriptor(
  name='Index',
  full_name='Request.Index',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='Request.Index.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=585,
)

_REQUEST_STYLETAG = _descriptor.Descriptor(
  name='StyleTag',
  full_name='Request.StyleTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='Request.StyleTag.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=587,
  serialized_end=614,
)

_REQUEST_ELEMENTSELECTORWITHOPTIONS = _descriptor.Descriptor(
  name='ElementSelectorWithOptions',
  full_name='Request.ElementSelectorWithOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ElementSelectorWithOptions.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='Request.ElementSelectorWithOptions.options', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=679,
)

_REQUEST_ELEMENTSELECTORWITHDURATION = _descriptor.Descriptor(
  name='ElementSelectorWithDuration',
  full_name='Request.ElementSelectorWithDuration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ElementSelectorWithDuration.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='Request.ElementSelectorWithDuration.duration', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=681,
  serialized_end=746,
)

_REQUEST_SELECTELEMENTSELECTOR = _descriptor.Descriptor(
  name='SelectElementSelector',
  full_name='Request.SelectElementSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.SelectElementSelector.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcherJson', full_name='Request.SelectElementSelector.matcherJson', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=810,
)

_REQUEST_JAVASCRIPTCODE = _descriptor.Descriptor(
  name='JavascriptCode',
  full_name='Request.JavascriptCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='script', full_name='Request.JavascriptCode.script', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=844,
)

_REQUEST_RAWJSON = _descriptor.Descriptor(
  name='RawJson',
  full_name='Request.RawJson',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='script', full_name='Request.RawJson.script', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=846,
  serialized_end=871,
)

_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_REQUEST_EMPTY, _REQUEST_SCREENSHOTPATH, _REQUEST_BROWSER, _REQUEST_CONTEXT, _REQUEST_URL, _REQUEST_TEXTINPUT, _REQUEST_ELEMENTPROPERTY, _REQUEST_TYPETEXT, _REQUEST_FILLTEXT, _REQUEST_CLEARTEXT, _REQUEST_PRESSKEYS, _REQUEST_ELEMENTSELECTOR, _REQUEST_TIMEOUT, _REQUEST_INDEX, _REQUEST_STYLETAG, _REQUEST_ELEMENTSELECTORWITHOPTIONS, _REQUEST_ELEMENTSELECTORWITHDURATION, _REQUEST_SELECTELEMENTSELECTOR, _REQUEST_JAVASCRIPTCODE, _REQUEST_RAWJSON, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21,
  serialized_end=871,
)


_SELECTENTRY = _descriptor.Descriptor(
  name='SelectEntry',
  full_name='SelectEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='SelectEntry.value', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='SelectEntry.label', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selected', full_name='SelectEntry.selected', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=934,
)


_RESPONSE_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='Response.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.Empty.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=949,
  serialized_end=969,
)

_RESPONSE_STRING = _descriptor.Descriptor(
  name='String',
  full_name='Response.String',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.String.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='Response.String.body', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1006,
)

_RESPONSE_BOOL = _descriptor.Descriptor(
  name='Bool',
  full_name='Response.Bool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.Bool.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='Response.Bool.body', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1041,
)

_RESPONSE_INT = _descriptor.Descriptor(
  name='Int',
  full_name='Response.Int',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.Int.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='Response.Int.body', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1043,
  serialized_end=1075,
)

_RESPONSE_SELECT = _descriptor.Descriptor(
  name='Select',
  full_name='Response.Select',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='Response.Select.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1077,
  serialized_end=1114,
)

_RESPONSE_JAVASCRIPTEXECUTIONRESULT = _descriptor.Descriptor(
  name='JavascriptExecutionResult',
  full_name='Response.JavascriptExecutionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.JavascriptExecutionResult.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='Response.JavascriptExecutionResult.result', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1116,
  serialized_end=1172,
)

_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RESPONSE_EMPTY, _RESPONSE_STRING, _RESPONSE_BOOL, _RESPONSE_INT, _RESPONSE_SELECT, _RESPONSE_JAVASCRIPTEXECUTIONRESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=1172,
)

_REQUEST_EMPTY.containing_type = _REQUEST
_REQUEST_SCREENSHOTPATH.containing_type = _REQUEST
_REQUEST_BROWSER.containing_type = _REQUEST
_REQUEST_CONTEXT.containing_type = _REQUEST
_REQUEST_URL.containing_type = _REQUEST
_REQUEST_TEXTINPUT.containing_type = _REQUEST
_REQUEST_ELEMENTPROPERTY.containing_type = _REQUEST
_REQUEST_TYPETEXT.containing_type = _REQUEST
_REQUEST_FILLTEXT.containing_type = _REQUEST
_REQUEST_CLEARTEXT.containing_type = _REQUEST
_REQUEST_PRESSKEYS.containing_type = _REQUEST
_REQUEST_ELEMENTSELECTOR.containing_type = _REQUEST
_REQUEST_TIMEOUT.containing_type = _REQUEST
_REQUEST_INDEX.containing_type = _REQUEST
_REQUEST_STYLETAG.containing_type = _REQUEST
_REQUEST_ELEMENTSELECTORWITHOPTIONS.containing_type = _REQUEST
_REQUEST_ELEMENTSELECTORWITHDURATION.containing_type = _REQUEST
_REQUEST_SELECTELEMENTSELECTOR.containing_type = _REQUEST
_REQUEST_JAVASCRIPTCODE.containing_type = _REQUEST
_REQUEST_RAWJSON.containing_type = _REQUEST
_RESPONSE_EMPTY.containing_type = _RESPONSE
_RESPONSE_STRING.containing_type = _RESPONSE
_RESPONSE_BOOL.containing_type = _RESPONSE
_RESPONSE_INT.containing_type = _RESPONSE
_RESPONSE_SELECT.fields_by_name['entry'].message_type = _SELECTENTRY
_RESPONSE_SELECT.containing_type = _RESPONSE
_RESPONSE_JAVASCRIPTEXECUTIONRESULT.containing_type = _RESPONSE
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['SelectEntry'] = _SELECTENTRY
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {

  'Empty' : _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_EMPTY,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Empty)
    })
  ,

  'ScreenshotPath' : _reflection.GeneratedProtocolMessageType('ScreenshotPath', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_SCREENSHOTPATH,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ScreenshotPath)
    })
  ,

  'Browser' : _reflection.GeneratedProtocolMessageType('Browser', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_BROWSER,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Browser)
    })
  ,

  'Context' : _reflection.GeneratedProtocolMessageType('Context', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_CONTEXT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Context)
    })
  ,

  'Url' : _reflection.GeneratedProtocolMessageType('Url', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_URL,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Url)
    })
  ,

  'TextInput' : _reflection.GeneratedProtocolMessageType('TextInput', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_TEXTINPUT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.TextInput)
    })
  ,

  'ElementProperty' : _reflection.GeneratedProtocolMessageType('ElementProperty', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_ELEMENTPROPERTY,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ElementProperty)
    })
  ,

  'TypeText' : _reflection.GeneratedProtocolMessageType('TypeText', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_TYPETEXT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.TypeText)
    })
  ,

  'FillText' : _reflection.GeneratedProtocolMessageType('FillText', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_FILLTEXT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.FillText)
    })
  ,

  'ClearText' : _reflection.GeneratedProtocolMessageType('ClearText', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_CLEARTEXT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ClearText)
    })
  ,

  'PressKeys' : _reflection.GeneratedProtocolMessageType('PressKeys', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_PRESSKEYS,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.PressKeys)
    })
  ,

  'ElementSelector' : _reflection.GeneratedProtocolMessageType('ElementSelector', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_ELEMENTSELECTOR,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ElementSelector)
    })
  ,

  'Timeout' : _reflection.GeneratedProtocolMessageType('Timeout', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_TIMEOUT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Timeout)
    })
  ,

  'Index' : _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_INDEX,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Index)
    })
  ,

  'StyleTag' : _reflection.GeneratedProtocolMessageType('StyleTag', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_STYLETAG,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.StyleTag)
    })
  ,

  'ElementSelectorWithOptions' : _reflection.GeneratedProtocolMessageType('ElementSelectorWithOptions', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_ELEMENTSELECTORWITHOPTIONS,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ElementSelectorWithOptions)
    })
  ,

  'ElementSelectorWithDuration' : _reflection.GeneratedProtocolMessageType('ElementSelectorWithDuration', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_ELEMENTSELECTORWITHDURATION,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ElementSelectorWithDuration)
    })
  ,

  'SelectElementSelector' : _reflection.GeneratedProtocolMessageType('SelectElementSelector', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_SELECTELEMENTSELECTOR,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.SelectElementSelector)
    })
  ,

  'JavascriptCode' : _reflection.GeneratedProtocolMessageType('JavascriptCode', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_JAVASCRIPTCODE,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.JavascriptCode)
    })
  ,

  'RawJson' : _reflection.GeneratedProtocolMessageType('RawJson', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_RAWJSON,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.RawJson)
    })
  ,
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'playwright_pb2'
  # @@protoc_insertion_point(class_scope:Request)
  })
_sym_db.RegisterMessage(Request)
_sym_db.RegisterMessage(Request.Empty)
_sym_db.RegisterMessage(Request.ScreenshotPath)
_sym_db.RegisterMessage(Request.Browser)
_sym_db.RegisterMessage(Request.Context)
_sym_db.RegisterMessage(Request.Url)
_sym_db.RegisterMessage(Request.TextInput)
_sym_db.RegisterMessage(Request.ElementProperty)
_sym_db.RegisterMessage(Request.TypeText)
_sym_db.RegisterMessage(Request.FillText)
_sym_db.RegisterMessage(Request.ClearText)
_sym_db.RegisterMessage(Request.PressKeys)
_sym_db.RegisterMessage(Request.ElementSelector)
_sym_db.RegisterMessage(Request.Timeout)
_sym_db.RegisterMessage(Request.Index)
_sym_db.RegisterMessage(Request.StyleTag)
_sym_db.RegisterMessage(Request.ElementSelectorWithOptions)
_sym_db.RegisterMessage(Request.ElementSelectorWithDuration)
_sym_db.RegisterMessage(Request.SelectElementSelector)
_sym_db.RegisterMessage(Request.JavascriptCode)
_sym_db.RegisterMessage(Request.RawJson)

SelectEntry = _reflection.GeneratedProtocolMessageType('SelectEntry', (_message.Message,), {
  'DESCRIPTOR' : _SELECTENTRY,
  '__module__' : 'playwright_pb2'
  # @@protoc_insertion_point(class_scope:SelectEntry)
  })
_sym_db.RegisterMessage(SelectEntry)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {

  'Empty' : _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_EMPTY,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.Empty)
    })
  ,

  'String' : _reflection.GeneratedProtocolMessageType('String', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_STRING,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.String)
    })
  ,

  'Bool' : _reflection.GeneratedProtocolMessageType('Bool', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_BOOL,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.Bool)
    })
  ,

  'Int' : _reflection.GeneratedProtocolMessageType('Int', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_INT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.Int)
    })
  ,

  'Select' : _reflection.GeneratedProtocolMessageType('Select', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_SELECT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.Select)
    })
  ,

  'JavascriptExecutionResult' : _reflection.GeneratedProtocolMessageType('JavascriptExecutionResult', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_JAVASCRIPTEXECUTIONRESULT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.JavascriptExecutionResult)
    })
  ,
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'playwright_pb2'
  # @@protoc_insertion_point(class_scope:Response)
  })
_sym_db.RegisterMessage(Response)
_sym_db.RegisterMessage(Response.Empty)
_sym_db.RegisterMessage(Response.String)
_sym_db.RegisterMessage(Response.Bool)
_sym_db.RegisterMessage(Response.Int)
_sym_db.RegisterMessage(Response.Select)
_sym_db.RegisterMessage(Response.JavascriptExecutionResult)



_PLAYWRIGHT = _descriptor.ServiceDescriptor(
  name='Playwright',
  full_name='Playwright',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1175,
  serialized_end=3370,
  methods=[
  _descriptor.MethodDescriptor(
    name='TakeScreenshot',
    full_name='Playwright.TakeScreenshot',
    index=0,
    containing_service=None,
    input_type=_REQUEST_SCREENSHOTPATH,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseBrowser',
    full_name='Playwright.CloseBrowser',
    index=1,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GoTo',
    full_name='Playwright.GoTo',
    index=2,
    containing_service=None,
    input_type=_REQUEST_URL,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GoBack',
    full_name='Playwright.GoBack',
    index=3,
    containing_service=None,
    input_type=_REQUEST_URL,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GoForward',
    full_name='Playwright.GoForward',
    index=4,
    containing_service=None,
    input_type=_REQUEST_URL,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTitle',
    full_name='Playwright.GetTitle',
    index=5,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetElementCount',
    full_name='Playwright.GetElementCount',
    index=6,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_INT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InputText',
    full_name='Playwright.InputText',
    index=7,
    containing_service=None,
    input_type=_REQUEST_TEXTINPUT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TypeText',
    full_name='Playwright.TypeText',
    index=8,
    containing_service=None,
    input_type=_REQUEST_TYPETEXT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FillText',
    full_name='Playwright.FillText',
    index=9,
    containing_service=None,
    input_type=_REQUEST_FILLTEXT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClearText',
    full_name='Playwright.ClearText',
    index=10,
    containing_service=None,
    input_type=_REQUEST_CLEARTEXT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDomProperty',
    full_name='Playwright.GetDomProperty',
    index=11,
    containing_service=None,
    input_type=_REQUEST_ELEMENTPROPERTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBoolProperty',
    full_name='Playwright.GetBoolProperty',
    index=12,
    containing_service=None,
    input_type=_REQUEST_ELEMENTPROPERTY,
    output_type=_RESPONSE_BOOL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTextContent',
    full_name='Playwright.GetTextContent',
    index=13,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUrl',
    full_name='Playwright.GetUrl',
    index=14,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Click',
    full_name='Playwright.Click',
    index=15,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Press',
    full_name='Playwright.Press',
    index=16,
    containing_service=None,
    input_type=_REQUEST_PRESSKEYS,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSelectContent',
    full_name='Playwright.GetSelectContent',
    index=17,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_SELECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SelectOption',
    full_name='Playwright.SelectOption',
    index=18,
    containing_service=None,
    input_type=_REQUEST_SELECTELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeselectOption',
    full_name='Playwright.DeselectOption',
    index=19,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CheckCheckbox',
    full_name='Playwright.CheckCheckbox',
    index=20,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UncheckCheckbox',
    full_name='Playwright.UncheckCheckbox',
    index=21,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Health',
    full_name='Playwright.Health',
    index=22,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetTimeout',
    full_name='Playwright.SetTimeout',
    index=23,
    containing_service=None,
    input_type=_REQUEST_TIMEOUT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddStyleTag',
    full_name='Playwright.AddStyleTag',
    index=24,
    containing_service=None,
    input_type=_REQUEST_STYLETAG,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HighlightElements',
    full_name='Playwright.HighlightElements',
    index=25,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTORWITHDURATION,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClickWithOptions',
    full_name='Playwright.ClickWithOptions',
    index=26,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTORWITHOPTIONS,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Focus',
    full_name='Playwright.Focus',
    index=27,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitForElementsState',
    full_name='Playwright.WaitForElementsState',
    index=28,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTORWITHOPTIONS,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecuteJavascriptOnPage',
    full_name='Playwright.ExecuteJavascriptOnPage',
    index=29,
    containing_service=None,
    input_type=_REQUEST_JAVASCRIPTCODE,
    output_type=_RESPONSE_JAVASCRIPTEXECUTIONRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPageState',
    full_name='Playwright.GetPageState',
    index=30,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_JAVASCRIPTEXECUTIONRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AutoActivatePages',
    full_name='Playwright.AutoActivatePages',
    index=31,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SwitchPage',
    full_name='Playwright.SwitchPage',
    index=32,
    containing_service=None,
    input_type=_REQUEST_INDEX,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SwitchContext',
    full_name='Playwright.SwitchContext',
    index=33,
    containing_service=None,
    input_type=_REQUEST_INDEX,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SwitchBrowser',
    full_name='Playwright.SwitchBrowser',
    index=34,
    containing_service=None,
    input_type=_REQUEST_INDEX,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePage',
    full_name='Playwright.CreatePage',
    index=35,
    containing_service=None,
    input_type=_REQUEST_URL,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateContext',
    full_name='Playwright.CreateContext',
    index=36,
    containing_service=None,
    input_type=_REQUEST_CONTEXT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateBrowser',
    full_name='Playwright.CreateBrowser',
    index=37,
    containing_service=None,
    input_type=_REQUEST_BROWSER,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PLAYWRIGHT)

DESCRIPTOR.services_by_name['Playwright'] = _PLAYWRIGHT

# @@protoc_insertion_point(module_scope)
